<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>ImportFile</name>
    <message>
        <location filename="../ImportFile.js" line="+68"/>
        <source>Error while importing file %1</source>
        <translation>ファイルインポート中のエラー %1</translation>
    </message>
    <message>
        <source>No import filters</source>
        <translation type="vanished">インポートフィルタがありません</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>No import filters have been found. Aborting...</source>
        <translation>インポートフィルタがみつかりません。中断します...</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>All Files</source>
        <translation>全てのファイル</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Import Drawing</source>
        <translation>インポート図面</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Format:</source>
        <translation>フォーマット:</translation>
    </message>
    <message>
        <location filename="../ImportFileInit.js" line="+2"/>
        <source>&amp;Import</source>
        <translation>&amp;I インポート</translation>
    </message>
</context>
</TS>
